%global gitrev 20161030

Name:           sayonara
Version:        0.9.2
Release:        4.git%{gitrev}%{?dist}
Summary:        A lightweight Qt Audio player

License:        GPLv3+
URL:            http://sayonara-player.com
# download instructions
# git clone https://git.sayonara-player.com/sayonara.git --branch 0.9.2-git11-20161030 sayonara-player
# tar cfz sayonara-player-0.9.2-git11-20161030.tar.gz sayonara-player
Source0:        %{name}-player-%{version}-git11-%{gitrev}.tar.gz

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  libappstream-glib
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qttools-devel
BuildRequires:  gstreamer1-plugins-base-devel
BuildRequires:  libnotify-devel
BuildRequires:  taglib-devel
BuildRequires:  libmtp-devel
Requires:       hicolor-icon-theme
Requires:       gstreamer1-plugins-bad-free

%description
%{name} is a small, clear, not yet platform-independent music player. Low 
CPU usage, low memory consumption and no long loading times are only three 
benefits of this player. Sayonara should be easy and intuitive to use and 
therefore it should be able to compete with the most popular music players.

%package        doc
Summary:        Documentation files for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
The %{name}-doc package contains html documentation
that use %{name}.


%prep
%setup -q -n %{name}-player

rm -rf .gitignore .git

%build
%cmake . -DCMAKE_BUILD_TYPE="RelWithDebInfo" \
         -DCMAKE_INSTALL_PREFIX=%{_prefix}
%make_build

# build docs
# update Doxyfile
doxygen -u doxygen/doxygen_config.cfg
# build docs
doxygen doxygen/doxygen_config.cfg

%install
%make_install

# remove menu dir, because it's not necessary
rm -rf %{buildroot}/%{_datadir}/menu

find %{buildroot}%{_datadir}/%{name}/translations -name "*.qm" | sed 's:'%{buildroot}'::
s:.*/\([a-zA-Z]\{2\}\).qm:%lang(\1) \0:' > %{name}.lang

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/*.appdata.xml

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
/usr/bin/update-desktop-database &> /dev/null || :

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files -f %{name}.lang
%license license.txt
%doc MANUAL README.txt
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.xpm
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/*/%{name}.png
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%dir %{_datadir}/%{name}/translations/icons
%{_datadir}/%{name}/translations/icons/*.png
%{_datadir}/%{name}/*.png
%{_datadir}/%{name}/*.ico
%{_datadir}/%{name}/*.css
%{_datadir}/%{name}/player.db
%{_datadir}/%{name}/soundcloud.db
%{_mandir}/man1/%{name}.1.gz

%files doc
%doc doxygen/html

%changelog
* Tue Nov 01 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.2-4.git20161030
- Rebuild for sayonara (git tag 0.9.2-git11-20161030)

* Mon Oct 10 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.2-3.git20161009
- Rebuild for sayonara (git tag 0.9.2-git5-20161009)

* Tue Sep 27 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.2-2.git20160920
- Add Requires gstreamer1-plugins-bad-free
- Rebuild for sayonara (git tag 0.9.2-git4-20160920)
- Spec file cleanup
- Changed git revision tag

* Wed Sep 14 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.2-1.20160920git
- Update to 0.9.2-1.20160920git

* Wed Sep 14 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.1-1.20160913git
- Update to 0.9.1-1.20160913git

* Wed Jun 08 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.0-2.20160607git
- Update to 0.9.0-2.20160607git

* Tue May 17 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.9.0-1.20160517git
- Update to 0.9.0

* Mon May 02 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.8.3-2.20160501git
- Update to new git release

* Mon Apr 25 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.8.3-1.20160424git
- Update to 0.8.3
- Added BR doxygen
- Added subpackage doc

* Tue Feb 16 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.8.2-1.20160214git
- Update to 0.8.2

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.1-2.svn324
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 16 2016 Martin Gansser <martinkg@fedoraproject.org> - 0.8.1-1.svn324
- Update to 0.8.1
- Added xpm icon path
- Added manual page

* Thu Dec 17 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.8.0-1.svn289
- Update to 0.8.0
- added BR libmtp-devel

* Thu Nov 26 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.7.1-4.svn257
- rebuild for new svn release

* Fri Oct 23 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.7.1-3.svn223
- rebuild for new svn release

* Sat Oct 17 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.7.1-2.svn211
- rebuild for new svn release

* Sun Oct 11 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.7.1-1.svn200
- Update to 0.7.1

* Wed Aug 26 2015 Lucio Carreras <luciocarreras@gmail.com> - 0.7.0-2.svn151
- fixed trailing spaces in Helper/MetaData/LibraryItem.cpp
- fixed soundcloud install dir issues
- fixed QObject dependencies neccessary under Fedora 22 in certain source files
- made Gstreamer mandatory

* Sat Aug 22 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.7.0-1.svn144
- rebuild for new svn release

* Fri Aug 14 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.6-6.svn119
- rebuild for new svn release

* Fri Jul 17 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.6-5.svn80
- rebuild for new svn release

* Thu Jul 16 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.6-4.svn73
- rebuild for new svn release

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.6-3.svn62
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun 04 2015 Lucio Carreras <luciocarreras@gmail.com> - 0.6.6-2.svn62
- added new CMake Build type option: RelWithDebInfo
- removed screenshots from sayonara.appdata.xml

* Sun May 24 2015 Lucio Carreras <luciocarreras@gmail.com> - 0.6.6-1.svn52
- changed server adress
- changed cmake call
- added -fPIC compiler flag for debug mode in CMakeLists.txt
- added sayonara.appdata.xml on SVN

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.6.5-2.svn1037
- Rebuilt for GCC 5 C++11 ABI change

* Tue Mar 31 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.5-1.svn1037
- rebuild for new svn release
- added 'if' conditions to fix f23 build

* Tue Feb 17 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.2-4.svn1021
- rebuild for new svn release

* Mon Feb 16 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.2-3.svn1018
- rebuild for new svn release
- cosmetic changes
- take ownership of unowned directory %%{_datadir}/%%{name}/translations
- take ownership of unowned directory %%{_datadir}/%%{name}/translations/icons

* Mon Feb 16 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.2-2.svn1016
- deleted BR  gstreamer1-devel because its redundant
- deleted RR svn isn't needed
- corrected license tag to GPLv3+
- added RR hicolor-icon-theme
- mark license files as %%license where available
- added appdata.xml file
- modified desktop file Categories
- removed java stuff
- added BR libappstream-glib

* Fri Feb 13 2015 Martin Gansser <martinkg@fedoraproject.org> - 0.6.2-1.svn1016
- rebuild for new svn release
- cleanup spec file

* Mon Sep 01 2014 Martin Gansser <martinkg@fedoraproject.org> - 0.4.1-1.4.svn878
- enabled debugging informations
- rebuild for new svn release
- set correct file permisson

* Fri Aug 29 2014 Martin Gansser <martinkg@fedoraproject.org> - 0.4.1-1.3.svn870
- rebuild for new svn release
- added more comments

* Tue Jun 10 2014 Martin Gansser <martinkg@fedoraproject.org> - 0.4.0-1.2.svn851
- removed unecessary BR glib2-devel
- removed unecessary BR alsa-lib-devel
- removed unecessary BR libxml2-devel

* Tue Jun 10 2014 Martin Gansser <martinkg@fedoraproject.org> - 0.4.0-1.2.svn851
- rebuild for new svn release
- added svn Requirement
- corrected svn path

* Mon Jun 09 2014 Martin Gansser <martinkg@fedoraproject.org> - 0.4.0-1.1.svn850
- added download instructions
- rebuild for new svn release

* Tue Oct 29 2013 Brendan Jones <brendan.jones.it@gmail.com> - 0.4.0-1.0.svn695
- Inital release.
